summaryrefslogtreecommitdiffstats
path: root/src/latin1literal.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/latin1literal.h')
-rw-r--r--src/latin1literal.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/latin1literal.h b/src/latin1literal.h
index 03e2293..72bc880 100644
--- a/src/latin1literal.h
+++ b/src/latin1literal.h
@@ -18,18 +18,18 @@
#ifndef LATIN1LITERAL_H
#define LATIN1LITERAL_H
-#include <qstring.h>
+#include <tqstring.h>
namespace Tellico {
/**
* A class for explicit marking of string literals encoded in the ISO
* 8859-1 character set. Allows for efficient, still (in terms of the
* chosen encoding) safe comparison with QString instances. To be used
* like this:
*
* \code
- * QString s = .....
+ * TQString s = .....
* if (s == Latin1Literal("o")) { ..... }
* \endcode
*
@@ -52,8 +52,8 @@ public:
} // end namespace
inline
-bool operator==(const QString& s1, const Tellico::Latin1LiteralInternal& s2) {
- const QChar* uc = s1.unicode();
+bool operator==(const TQString& s1, const Tellico::Latin1LiteralInternal& s2) {
+ const TQChar* uc = s1.tqunicode();
const char* c = s2.str;
if(!c || !uc) {
return (!c && !uc);
@@ -65,7 +65,7 @@ bool operator==(const QString& s1, const Tellico::Latin1LiteralInternal& s2) {
}
for(size_t i = 0; i < l; ++i, ++uc, ++c) {
- if(uc->unicode() != static_cast<uchar>(*c)) {
+ if(uc->tqunicode() != static_cast<uchar>(*c)) {
return false;
}
}
@@ -73,17 +73,17 @@ bool operator==(const QString& s1, const Tellico::Latin1LiteralInternal& s2) {
}
inline
-bool operator!=(const QString& s1, const Tellico::Latin1LiteralInternal& s2) {
+bool operator!=(const TQString& s1, const Tellico::Latin1LiteralInternal& s2) {
return !(s1 == s2);
}
inline
-bool operator==(const Tellico::Latin1LiteralInternal& s1, const QString& s2) {
+bool operator==(const Tellico::Latin1LiteralInternal& s1, const TQString& s2) {
return s2 == s1;
}
inline
-bool operator!=(const Tellico::Latin1LiteralInternal& s1, const QString& s2) {
+bool operator!=(const Tellico::Latin1LiteralInternal& s1, const TQString& s2) {
return !(s2 == s1);
}
@@ -18,18 +18,18 @@
* A class for explicit marking of string literals encoded in the ISO
* 8859-1 character set. Allows for efficient, still (in terms of the
- * chosen encoding) safe comparison with QString instances. To be used
+ * chosen encoding) safe comparison with TQString instances. To be used
* like this:
*